@@ -2,4 +2,5 @@ from .chai_bot import ChaiBot
 from .types import LatestMessage, Update, Message, MessageKind
 from .t_room import TRoom
 from .packaging import package, Metadata
-from .deployment import upload_and_deploy, wait_for_deployment, get_bot_status
+from .deployment import upload_and_deploy, wait_for_deployment, get_bot_status, share_bot
+from .notebook_utils import IS_NOTEBOOK, setup_notebook
