@@ -5,6 +5,7 @@ from typing import AnyStr, Optional
 import requests
 import segno
 from halo import Halo
+from requests import HTTPError
 from typing_extensions import TypedDict
 
 from .defaults import DEFAULT_BOT_STATUS_ENDPOINT, DEFAULT_SIGNED_URL_CREATOR, GUEST_KEY, GUEST_UID
@@ -99,10 +100,13 @@ def wait_for_deployment(bot_uid: str, sleep: float = 3):
     completed_processes = []
     existing_status = None
     try:
-        existing_status = get_bot_status(bot_uid)
-        print(f"Found previous deployment: Version {existing_status['activeDeployment']['version']}")
-    except Exception:
-        pass
+        _existing_status = get_bot_status(bot_uid)
+        if "activeDeployment" in _existing_status:
+            existing_status = _existing_status
+            print(f"Found previous deployment: Version {existing_status['activeDeployment']['version']}")
+    except HTTPError as e:
+        if e.response.status_code != 404:
+            raise e
 
     MAXIMUM_ERROR_RETRIES = 10
     error_retries = 0
